#include "precompile.h"

#include "bag.h"
#include "human.h"
#include "room.h"

#include "mt/Equip.h"
#include "mt/Item.h"
#include "mt/BattlePotion.h"

int BagItem::GetCdTime(Human* hum)
{
    if (last_use_tick <= 0) {
        return 0;
    }
    if (!potion_meta) {
        return 0;
    }
    return std::max(0.0f,
                    (potion_meta->cooldown() * SERVER_FRAME_RATE - (hum->room->GetFrameNo() - last_use_tick)) * FRAME_RATE_MS);
}

void Bag::Parse(const std::list<std::tuple<int, int, int, int>>& items)
{
    for (auto tuple : items) {
        auto item_id = std::get<0>(tuple);
        auto item_num = std::get<1>(tuple);
        auto item_meta = mt::Item::GetById(item_id);
        if (item_meta) {
            auto potion_meta = mt::BattlePotion::GetById(item_id);
            auto equip_meta = mt::Equip::GetById(item_meta->relationship());
            if (potion_meta && equip_meta) {
                auto p = std::make_shared<BagItem>();
                p->equip_id = equip_meta->id();
                p->equip_num = item_num;
                p->item_meta = item_meta;
                p->potion_meta = potion_meta;
                p->equip_meta = equip_meta;
                items_[p->equip_id] = p;
            }
        }
    }
}

std::shared_ptr<BagItem> Bag::GetItemByEquipId(int equip_id)
{
    auto itr = items_.find(equip_id);
    return itr != items_.end() ? itr->second : nullptr;
}

std::shared_ptr<BagItem> Bag::GetItemByItemId(int item_id)
{
    for (auto pair : items_) {
        auto item = pair.second;
        if (item->item_meta && item->item_meta->id() == item_id) {
            return item;
        }
    }
    return nullptr;
}
